Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BinaryCodec ¶
type BinaryCodec interface {
Marshal(transaction.Msg) ([]byte, error)
Unmarshal([]byte, transaction.Msg) error
}
BinaryCodec defines a binary encoding and decoding interface for modules to encode and decode data.
type Codec ¶
type Codec interface {
BinaryCodec
JSONCodec
}
Codec defines a Binary Codec and JSON Codec for modules to encode and decode data.
type JSONCodec ¶
type JSONCodec interface {
MarshalJSON(transaction.Msg) ([]byte, error)
UnmarshalJSON([]byte, transaction.Msg) error
}
JSONCodec defines a JSON encoding and decoding interface for modules to encode and decode data.
Click to show internal directories.
Click to hide internal directories.